@@ -12,7 +12,10 @@ import unittest
 import doctest
 import re
 
-from gevent import Timeout
+import gevent
+
+class WaitTimeout:
+    pass
 
 
 class ToolException(Exception):
@@ -122,6 +125,9 @@ class ToolError:
     def strerror(self):
         return self.codes[self.code]
 
+    def __str__(self):
+        return self.message
+
 
 class Tool(object):
     '''
@@ -177,7 +183,7 @@ class Tool(object):
         @classmethod
         __format_help__()
             output: format help string
-                
+
                 Implement to provide output formatting specific help for this
                 tool.
 
@@ -229,13 +235,18 @@ class Tool(object):
         timeout = None
         if not self.options.wait is None:
             wait = float(self.options.wait)
-            timeout = Timeout(wait)
+            timeout = gevent.Timeout(wait)
         try:
             try:
                 result = self._call(item, iterator)
-            except Timeout, t:
+            except gevent.Timeout, t:
                 if t is not timeout:
                     raise
+                #
+                # Do some handling, if Timeout works...
+                #
+            except WaitTimeout, e:
+                self.set_error('wait-timeout')
             finally:
                 if timeout:
                     timeout.cancel()
@@ -249,7 +260,7 @@ class Tool(object):
 
             always returns self
         '''
-        self._item = item  # used in filename by --split-output
+        self._item = str(item).strip()  # used in filename by --split-output
         parse_result = None
         action_result = None
         #
@@ -276,6 +287,7 @@ class Tool(object):
         action_result = self.__action__(parse_result)
         if action_result is None or not self.error is None:
             if self.error is None:
+                print 'kk IT IS NONE', parse_result
                 code = ToolError.ActionFailed
                 error = ToolError(code)
                 self.set_error(error)
@@ -322,7 +334,10 @@ class Tool(object):
     def error(self):
         return self._error
 
-    def set_error(self, error):
+    def set_error(self, error, oneword=False):
+        if oneword:
+            error = str(error).lower()
+            error = error.replace(' ', '-')
         self._error = error
 
     def __str__(self):
