@@ -19,8 +19,8 @@ class DummyTool(Tool):
     ]
 
     @classmethod
-    def print_source(self):
-        print open(__file__).read()
+    def print_source(cls):
+        cls._print_source(__file__)
 
     def __parse__(self, line, iterator):
         item = line.strip()
