@@ -205,7 +205,12 @@ class WebgetTool(Tool):
                         self.set_error(msg)
                         return None
 
-                    if lurl.scheme and lurl.scheme.lower() != ourl.scheme.lower():
+                    if ourl.scheme.lower() == 'http' and lurl.scheme.lower() == 'https':
+                        #
+                        # Allow http to https but nothing else.
+                        #
+                        pass
+                    elif lurl.scheme and lurl.scheme.lower() != ourl.scheme.lower():
                         msg = 'redirect-host-mismatch {0}'.format(location)
                         self.set_error(msg)
                         return None
